HilbertCPCCARotator
===================

.. currentmodule:: xeofs.cross

.. autoclass:: HilbertCPCCARotator
   :members:
   :inherited-members:

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~HilbertCPCCARotator.__init__
      ~HilbertCPCCARotator.components
      ~HilbertCPCCARotator.components_amplitude
      ~HilbertCPCCARotator.components_phase
      ~HilbertCPCCARotator.compute
      ~HilbertCPCCARotator.correlation_coefficients_X
      ~HilbertCPCCARotator.correlation_coefficients_Y
      ~HilbertCPCCARotator.cross_correlation_coefficients
      ~HilbertCPCCARotator.deserialize
      ~HilbertCPCCARotator.fit
      ~HilbertCPCCARotator.fraction_variance_X_explained_by_X
      ~HilbertCPCCARotator.fraction_variance_Y_explained_by_X
      ~HilbertCPCCARotator.fraction_variance_Y_explained_by_Y
      ~HilbertCPCCARotator.get_params
      ~HilbertCPCCARotator.get_serialization_attrs
      ~HilbertCPCCARotator.heterogeneous_patterns
      ~HilbertCPCCARotator.homogeneous_patterns
      ~HilbertCPCCARotator.inverse_transform
      ~HilbertCPCCARotator.load
      ~HilbertCPCCARotator.predict
      ~HilbertCPCCARotator.save
      ~HilbertCPCCARotator.scores
      ~HilbertCPCCARotator.scores_amplitude
      ~HilbertCPCCARotator.scores_phase
      ~HilbertCPCCARotator.serialize
      ~HilbertCPCCARotator.squared_covariance_fraction
      ~HilbertCPCCARotator.transform
   
   

   
   
   